---
title: 택배사 코드
description: 에스크로 배송등록에 필요한 택배사 코드표를 확인합니다.
targetVersions:
  - v1
---

**이용하시는 PG사 상관없이 동일한 코드표가 적용됩니다.**

|택배사 코드|택배사 이름                                                        |
|-----------|-------------------------------------------------------------------|
|`HYUNDAI`  |롯데택배                                                           |
|`HANARO`   |하나로택배                                                         |
|`SAGAWA`   |SC로지스                                                           |
|`KGB`      |로젠택배                                                           |
|`YELLOWCAP`|옐로우캡                                                           |
|`DONGBU`   |동부택배                                                           |
|`EPOST`    |우체국택배                                                         |
|`CJGLS`    |CJ대한통운                                                         |
|`HANJIN`   |한진택배                                                           |
|`DAESIN`   |대신택배                                                           |
|`ETC`      |기타(위 코드표에 해당되지 않는 값이 전달되면 ETC로 자동 처리됩니다)|
